@@ -2,9 +2,15 @@ import array
 import copy
 from collections import OrderedDict
 
-from PyQt5.QtCore import pyqtSlot, QAbstractTableModel, QModelIndex, Qt, QRegExp
-from PyQt5.QtGui import QRegExpValidator
-from PyQt5.QtWidgets import QWidget, QHeaderView, QAbstractItemView, QLineEdit
+from PyQt6.QtCore import (
+    pyqtSlot,
+    QAbstractTableModel,
+    QModelIndex,
+    Qt,
+    QRegularExpression,
+)
+from PyQt6.QtGui import QRegularExpressionValidator
+from PyQt6.QtWidgets import QWidget, QHeaderView, QAbstractItemView, QLineEdit
 
 from urh.signalprocessing.ChecksumLabel import ChecksumLabel
 from urh.signalprocessing.Message import Message
@@ -55,18 +61,21 @@ class ChecksumWidget(QWidget):
         def rowCount(self, parent: QModelIndex = None, *args, **kwargs):
             return len(self.checksum_label.data_ranges)
 
-        def headerData(self, section, orientation, role=Qt.DisplayRole):
-            if role == Qt.DisplayRole and orientation == Qt.Horizontal:
+        def headerData(self, section, orientation, role=Qt.ItemDataRole.DisplayRole):
+            if (
+                role == Qt.ItemDataRole.DisplayRole
+                and orientation == Qt.Orientation.Horizontal
+            ):
                 return self.header_labels[section]
             return super().headerData(section, orientation, role)
 
-        def data(self, index: QModelIndex, role=Qt.DisplayRole):
+        def data(self, index: QModelIndex, role=Qt.ItemDataRole.DisplayRole):
             if not index.isValid():
                 return None
 
             i, j = index.row(), index.column()
 
-            if role == Qt.DisplayRole:
+            if role == Qt.ItemDataRole.DisplayRole:
                 data_range = self.checksum_label.data_ranges[i]
                 if j == 0:
                     return (
@@ -111,14 +120,18 @@ class ChecksumWidget(QWidget):
 
         def flags(self, index):
             if not index.isValid():
-                return Qt.NoItemFlags
+                return Qt.ItemFlag.NoItemFlags
 
             try:
                 _ = self.checksum_label.data_ranges[index.row()]
             except IndexError:
-                return Qt.NoItemFlags
+                return Qt.ItemFlag.NoItemFlags
 
-            return Qt.ItemIsEditable | Qt.ItemIsEnabled | Qt.ItemIsSelectable
+            return (
+                Qt.ItemFlag.ItemIsEditable
+                | Qt.ItemFlag.ItemIsEnabled
+                | Qt.ItemFlag.ItemIsSelectable
+            )
 
     def __init__(
         self,
@@ -141,10 +154,12 @@ class ChecksumWidget(QWidget):
             1, SpinBoxDelegate(1, 999999, self)
         )
         self.ui.tableViewDataRanges.horizontalHeader().setSectionResizeMode(
-            QHeaderView.Stretch
+            QHeaderView.ResizeMode.Stretch
         )
         self.ui.tableViewDataRanges.setModel(self.data_range_table_model)
-        self.ui.tableViewDataRanges.setEditTriggers(QAbstractItemView.AllEditTriggers)
+        self.ui.tableViewDataRanges.setEditTriggers(
+            QAbstractItemView.EditTrigger.AllEditTriggers
+        )
         self.display_crc_data_ranges_in_table()
         self.ui.comboBoxCRCFunction.addItems(
             [crc_name for crc_name in GenericCRC.DEFAULT_POLYNOMIALS]
@@ -153,7 +168,7 @@ class ChecksumWidget(QWidget):
             [special_crc_name for special_crc_name in self.SPECIAL_CRCS]
         )
         self.ui.lineEditCRCPolynomial.setValidator(
-            QRegExpValidator(QRegExp("[0-9,a-f]*"))
+            QRegularExpressionValidator(QRegularExpression("[0-9,a-f]*"))
         )
         self.ui.comboBoxCategory.clear()
         for _, member in self.checksum_label.Category.__members__.items():
